==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/webaccess/src/webaccess_ca_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="171"/>
        <source>Loading project...</source>
        <translation>Carregant projecte...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="207"/>
        <source>Fixture stored and loaded</source>
        <translation>Fixture desat i carregat</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="407"/>
        <source>Username and password are required fields.</source>
        <translation>El nom d&apos;usuari i la contrasenya són camps obligatoris.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="413"/>
        <location filename="webaccess.cpp" line="438"/>
        <source>User level has to be a positive integer.</source>
        <translation>El nivell d&apos;usuari ha de ser un enter positiu.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="432"/>
        <source>Username is required.</source>
        <translation>El nom d&apos;usuari es obligatori.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="450"/>
        <source>Error while saving passwords file.</source>
        <translation>S&apos;ha produït un error en desar el fitxer de contrasenyes.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="465"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configuració de xarxa ha canviar. Reiniciar per aplicar els canvis.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Autostart configuration changed</source>
        <translation>La configuració d&apos;inici automàtic ha canviat</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="860"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Widget no suportat (encara) per accés web</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="912"/>
        <location filename="webaccess.cpp" line="965"/>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1131"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1163"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1164"/>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1165"/>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1166"/>
        <source>Duration</source>
        <translation>Duració</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1167"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1463"/>
        <source>Load project</source>
        <translation>Carregar projecte</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1465"/>
        <source>Simple Desk</source>
        <translation>Taula Simple</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1467"/>
        <source>Configuration</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Carregar fixture</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Contrassenya</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Nivell d&apos;accès</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Deixar en blanc per no canviar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Només Consola Virtual</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Consola Virtual i Taula Simple</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Tot</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Canviar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Suprimeix l&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Nou nom d&apos;usuari...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Nova contrassenya...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>El nom d&apos;usuari i la contrasenya són camps obligatoris.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Afegir usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: si no hi ha almenys un usuari amb nivell d&apos;accés &quot;Tot&quot; a la llista d&apos;autorització, es desactivarà.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="323"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="332"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="340"/>
        <source>Universes configuration</source>
        <translation>Configuració d&apos;universos</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="347"/>
        <source>Audio configuration</source>
        <translation>Configuració d&apos;àudio</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="355"/>
        <source>User loaded fixtures</source>
        <translation>Fixtures carregat per l&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="364"/>
        <source>Authorized users</source>
        <translation>Usuaris autoritzats</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="101"/>
        <source>Network interface: </source>
        <translation>Interfície de xarxa:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="106"/>
        <source>Access point name (SSID): </source>
        <translation>Nom del punt d&apos;accés (SSID):</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="108"/>
        <source>WPA-PSK Password: </source>
        <translation>Contrasenya WPA-PSK:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="113"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dinàmica (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="115"/>
        <source>Static</source>
        <translation>Estàtica</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="119"/>
        <source>IP Address: </source>
        <translation>Direcció IP:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="121"/>
        <source>Netmask: </source>
        <translation>Màscara de xarxa:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="123"/>
        <source>Gateway: </source>
        <translation>Porta d&apos;enllaç:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="126"/>
        <location filename="webaccessnetwork.cpp" line="344"/>
        <source>Apply changes</source>
        <translation>Aplicar canvis</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="327"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="333"/>
        <source>Network configuration</source>
        <translation>Configuració de xarxa</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="338"/>
        <source>Project autostart</source>
        <translation>Inici automàtic del projecte</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>No project</source>
        <translation>Cap projecte</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Use current project</source>
        <translation>Emprar el projecte actual</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="349"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Pàgina anterior</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Pròxima pàgina</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Reinicia univers</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.3.orig.tar.xz: qlcplus-QLC-_4.14.3/webaccess/src/webaccess_ca_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="172"/>
        <source>Loading project...</source>
        <translation>Carregant projecte...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="208"/>
        <source>Fixture stored and loaded</source>
        <translation>Fixture desat i carregat</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="408"/>
        <source>Username and password are required fields.</source>
        <translation>El nom d&apos;usuari i la contrasenya són camps obligatoris.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="414"/>
        <location filename="webaccess.cpp" line="439"/>
        <source>User level has to be a positive integer.</source>
        <translation>El nivell d&apos;usuari ha de ser un enter positiu.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="433"/>
        <source>Username is required.</source>
        <translation>El nom d&apos;usuari es obligatori.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="451"/>
        <source>Error while saving passwords file.</source>
        <translation>S&apos;ha produït un error en desar el fitxer de contrasenyes.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="466"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>La configuració de xarxa ha canviar. Reiniciar per aplicar els canvis.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="468"/>
        <source>An error occurred while updating the network configuration.</source>
        <translation>S&apos;ha produït un error en actualitzar la configuració de la xarxa.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Wi-Fi hotspot successfully activated.</source>
        <translation>El punt d&apos;accés Wi-Fi s&apos;ha activat correctament.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="486"/>
        <source>An error occurred while creating a Wi-Fi hotspot.</source>
        <translation>S&apos;ha produït un error en crear un punt d&apos;accés Wi-Fi.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="491"/>
        <source>Wi-Fi hotspot successfully deactivated.</source>
        <translation>El punt d&apos;accés Wi-Fi s&apos;ha desactivat correctament.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="507"/>
        <source>Autostart configuration changed</source>
        <translation>La configuració d&apos;inici automàtic ha canviat</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1014"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Widget no suportat (encara) per accés web</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1440"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1643"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1644"/>
        <source>Fade In</source>
        <translation>Fade In</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1645"/>
        <source>Fade Out</source>
        <translation>Fade Out</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1646"/>
        <source>Duration</source>
        <translation>Duració</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1647"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2076"/>
        <source>Color 2 Reset</source>
        <translation>Restableix Color 2</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2085"/>
        <source>Color 3 Reset</source>
        <translation>Restableix Color 3</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2094"/>
        <source>Color 4 Reset</source>
        <translation>Restableix Color 4</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2103"/>
        <source>Color 5 Reset</source>
        <translation>Restableix Color 5</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2345"/>
        <source>Load project</source>
        <translation>Carregar projecte</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2347"/>
        <source>Simple Desk</source>
        <translation>Taula Simple</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2349"/>
        <source>Configuration</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Passthrough</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Carregar fixture</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation>Contrassenya</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation>Nivell d&apos;accès</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation>Deixar en blanc per no canviar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation>Només Consola Virtual</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation>Consola Virtual i Taula Simple</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation>Tot</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation>Canviar</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation>Suprimeix l&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation>Nou nom d&apos;usuari...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation>Nova contrassenya...</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation>El nom d&apos;usuari i la contrasenya són camps obligatoris.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation>Afegir usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation>Nota: si no hi ha almenys un usuari amb nivell d&apos;accés &quot;Tot&quot; a la llista d&apos;autorització, es desactivarà.</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="322"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="331"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="339"/>
        <source>Universes configuration</source>
        <translation>Configuració d&apos;universos</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="346"/>
        <source>Audio configuration</source>
        <translation>Configuració d&apos;àudio</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="354"/>
        <source>User loaded fixtures</source>
        <translation>Fixtures carregat per l&apos;usuari</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="363"/>
        <source>Authorized users</source>
        <translation>Usuaris autoritzats</translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="114"/>
        <source>Wi-Fi Hotspot</source>
        <translation>Punt d&apos;accés Wi-Fi</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="118"/>
        <location filename="webaccessnetwork.cpp" line="136"/>
        <source>Access point name (SSID): </source>
        <translation>Nom del punt d&apos;accés (SSID): </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="120"/>
        <location filename="webaccessnetwork.cpp" line="138"/>
        <source>WPA-PSK Password: </source>
        <translation>Contrasenya WPA-PSK: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="124"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="125"/>
        <source>Disable</source>
        <translation>Desactivar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="130"/>
        <source>Network interface</source>
        <translation>Interfície de xarxa</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="144"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dinàmica (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="146"/>
        <source>Static</source>
        <translation>Estàtica</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="151"/>
        <source>IP Address: </source>
        <translation>Adreça IP: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="153"/>
        <source>Netmask: </source>
        <translation>Màscara de xarxa: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="155"/>
        <source>Gateway: </source>
        <translation>Porta d&apos;enllaç: </translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="158"/>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Apply changes</source>
        <translation>Aplicar canvis</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="326"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="332"/>
        <source>Network configuration</source>
        <translation>Configuració de xarxa</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="337"/>
        <source>Project autostart</source>
        <translation>Inici automàtic del projecte</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="341"/>
        <source>No project</source>
        <translation>Cap projecte</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>Use current project</source>
        <translation>Emprar el projecte actual</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="347"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Shutdown</source>
        <translation>Apagar</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Pàgina</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Pàgina anterior</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Pròxima pàgina</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Reinicia univers</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Univers</translation>
    </message>
</context>
</TS>
